# Acknowledgement

If you use this package in your work, please cite it using the following bibtex entry:

```
@software{portrait,
    author = {Garcia, Lionel},
    license = {MIT},
    title = {{portrait}},
    url = {https://github.com/lgrcia/portrait}
}
```